@@ -14,15 +14,15 @@
 from flask import current_app as app
 from common import get_document
 from flask import abort
-from ..utils import config
+from eve.utils import config
 
 
 def delete(resource, **lookup):
-    """Deletes a resource item. Deletion occurs only if the request ETag
+    """Deletes a resource item. Deletion will occur only if request ETag
     matches the current representation of the item.
 
-    :param resource: name of the resource to which the item belongs.
-    :param **lookup: item lookup query
+    :param resource: name of the resource to which the item(s) belong.
+    :param **lookup: item lookup query.
     """
     original = get_document(resource, **lookup)
     if not original:
@@ -30,3 +30,13 @@ def delete(resource, **lookup):
 
     app.data.remove(resource, lookup[config.ID_FIELD])
     return dict(), None, None, 200
+
+
+def delete_resource(resource):
+    """Deletes all item of a resource (collection in MongoDB terms). Won't drop
+    indexes. Use with caution!
+
+    .. versionadded:: 0.0.2
+    """
+    app.data.remove(resource)
+    return dict(), None, None, 200
