@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-)
 
 """
     eve.render
@@ -39,10 +39,8 @@ def send_response(resource, dct, last_modified=None, etag=None, status=200):
     # along with the corresponding render function.
     mime, renderer = _best_mime()
 
-    response = {'response': dct}
-
     # invoke the render function and obtain the corresponding rendered item
-    rendered = globals()[renderer](**response)
+    rendered = globals()[renderer](**dct)
 
     # build the main wsgi rensponse object
     resp = make_response(rendered, status)
@@ -110,34 +108,122 @@ def render_json(**data):
     return json.dumps(data, cls=APIEncoder)
 
 
-def render_xml(**d):
-    """ XML render function. This could surely use some further tinkering.
+def render_xml(**data):
+    """ XML render function.
+
+    :param data: the data stream to be rendered as xml.
+
+    .. versionchanged:: 0.0.3
+       Support for HAL-like hyperlinks and resource descriptors.
+    """
+    if data:
+        xml = xml_root_open(data)
+        xml += xml_add_links(data)
+        xml += xml_add_items(data)
+        xml += xml_root_close()
+    return '' or xml
+
+
+def xml_root_open(data):
+    """ Returns the opening tag for the XML root node. If the datastream
+    includes informations about resource endpoints (href, title), they will
+    be added as node attributes. The resource endpoint is then removed to allow
+    for further processing of the datastream.
+
+    :param data: the data stream to be rendered as xml.
+
+    .. versionadded:: 0.0.3
+    """
+    links = data.get('_links')
+    href = title = ''
+    if links and 'self' in links:
+        self_ = links.pop('self')
+        href = ' href="%s" ' % self_['href']
+        if 'title' in self_:
+            title = ' title="%s" ' % self_['title']
+    return '<resource%s%s>' % (href, title)
+
+
+def xml_add_links(data):
+    """ Returns as many <link> nodes as there are in the datastream. The links
+    are then removed from the datastream to allow for further processing.
+
+    :param data: the data stream to be rendered as xml.
+
+    .. versionadded:: 0.0.3
+    """
+    chunk = '<link rel="%s" href="%s" title="%s" />'
+    links = data.pop('_links', {})
+    xml = ''
+    for rel, link in links.items():
+        if isinstance(link, list):
+            xml += ''.join([chunk % (rel, d['href'], d['title']) for d in
+                            link])
+        else:
+            xml += ''.join(chunk % (rel, link['href'], link['title']))
+    return xml
+
+
+def xml_add_items(data):
+    """ When this function is called the datastream can only contain a `_items`
+    list, or a dictionary. If a list, each item is a resource which rendered as
+    XML. If a dictionary, it will be rendered as XML.
+
+    :param data: the data stream to be rendered as xml.
+
+    .. versionadded:: 0.0.3
+    """
+    try:
+        xml = ''.join([xml_item(item) for item in data['_items']])
+    except:
+        xml = xml_dict(data)
+    return xml
+
+
+def xml_item(item):
+    """ Represents a single resource (member of a collection) as XML.
+
+    :param data: the data stream to be rendered as xml.
+
+    .. versionadded:: 0.0.3
+    """
+    xml = xml_root_open(item)
+    xml += xml_add_links(item)
+    xml += xml_dict(item)
+    xml += xml_root_close()
+    return xml
+
+
+def xml_root_close():
+    """ Returns the closing tag of the XML root node.
+
+    .. versionadded:: 0.0.3
+    """
+    return '</resource>'
+
+
+def xml_dict(data):
+    """ Renders a dict as XML.
+
+    :param data: the data stream to be rendered as xml.
+
+    .. versionadded:: 0.0.3
     """
     xml = ''
-    for k, v in d.items():
+    for k, v in data.items():
         if isinstance(v, datetime.datetime):
             v = date_to_str(v)
         elif isinstance(v, (datetime.time, datetime.date)):
             v = v.isoformat()
-        if type(v) is dict:
-            xml += "<%s>" % (k.rstrip('s'))
-            xml += render_xml(**v)
-            xml += "</%s>" % (k.rstrip('s'))
-        else:
-            original_list = False
-            if type(v) is not list:
-                v = [v]
-            else:
-                original_list = True
+        if not isinstance(v, list):
+            v = [v]
+        for value in v:
+            if isinstance(value, dict):
+                links = xml_add_links(value)
                 xml += "<%s>" % k
-            for value in v:
-                if type(value) is dict:
-                    xml += "<%s>" % (k.rstrip('s'))
-                    xml += render_xml(**value)
-                    xml += "</%s>" % (k.rstrip('s'))
-                else:
-                    xml += "<%s>%s</%s>" % (str(k.rstrip('s')), value,
-                                            str(k.rstrip('s')))
-            if original_list:
+                xml += xml_dict(value)
+                xml += links
                 xml += "</%s>" % k
+            else:
+                xml += "<%s>%s</%s>" % (k, value, k)
     return xml
