@@ -62,8 +62,9 @@ class TestMethodsBase(TestBase):
 
     def setUp(self):
         super(TestMethodsBase, self).setUp()
+        self.setupDB()
         response, status = self.get('contacts', '?max_results=2')
-        contact = response['contacts'][0]
+        contact = response['_items'][0]
         self.item_id = contact[self.app.config['ID_FIELD']]
         self.item_name = contact['ref']
         self.item_tid = contact['tid']
@@ -74,13 +75,16 @@ class TestMethodsBase(TestBase):
         self.item_name_url = ('/%s/%s/' %
                               (self.domain[self.known_resource]['url'],
                                self.item_name))
-        self.alt_ref = response['contacts'][1]['ref']
+        self.alt_ref = response['_items'][1]['ref']
 
         response, status = self.get('payments', '?max_results=1')
-        self.readonly_id = response['payments'][0]['_id']
+        self.readonly_id = response['_items'][0]['_id']
         self.readonly_id_url = ('%s%s/' % (self.readonly_resource_url,
                                            self.readonly_id))
 
+    def tearDown(self):
+        self.dropDB()
+
     def get(self, resource, query='', item=None):
         if resource in self.domain:
             resource = self.domain[resource]['url']
@@ -93,7 +97,7 @@ class TestMethodsBase(TestBase):
         return self.parse_response(r)
 
     def parse_response(self, r):
-        v = json.loads(r.data)['response'] if r.status_code == 200 else None
+        v = json.loads(r.data) if r.status_code == 200 else None
         return v, r.status_code
 
     def assertValidationError(self, response, key, matches):
@@ -135,7 +139,7 @@ class TestMethodsBase(TestBase):
         self.assertEqual(r.data, '')
 
     def assertItem(self, item):
-        self.assertIs(type(item), dict)
+        self.assertEqual(type(item), dict)
 
         _id = item.get(self.app.config['ID_FIELD'])
         self.assertTrue(_id is not None)
@@ -151,49 +155,61 @@ class TestMethodsBase(TestBase):
             self.fail('Cannot convert field "%s" to datetime: %s' %
                       (self.app.config['LAST_UPDATED'], e))
 
-        link = item.get('link')
-        self.assertTrue(link is not None)
+        link = item.get('_links')
         self.assertItemLink(link, _id)
 
     def assertHomeLink(self, links):
-        found = False
-        for link in links:
-            if "title='home'" in link and \
-               "href='%s'" % self.app.config['SERVER_NAME'] in link:
-                found = True
-                break
-        self.assertTrue(found)
+        self.assertTrue('parent' in links)
+        link = links['parent']
+        self.assertTrue('title' in link)
+        self.assertTrue('href' in link)
+        self.assertEqual('home', link['title'])
+        self.assertEqual("%s" % self.app.config['SERVER_NAME'], link['href'])
 
     def assertResourceLink(self, links, resource):
+        self.assertTrue('self' in links)
+        link = links['self']
+        self.assertTrue('title' in link)
+        self.assertTrue('href' in link)
         url = self.domain[resource]['url']
-        found = False
-        for link in links:
-            if "title='%s'" % url in link and \
-               "href='%s/%s/" % (self.app.config['SERVER_NAME'], url) in link:
-                found = True
-                break
-        self.assertTrue(found)
+        self.assertEqual(url, link['title'])
+        self.assertEqual("%s/%s/" % (self.app.config['SERVER_NAME'], url),
+                         link['href'])
+
+    def assertCollectionLink(self, links, resource):
+        self.assertTrue('collection' in links)
+        link = links['collection']
+        self.assertTrue('title' in link)
+        self.assertTrue('href' in link)
+        url = self.domain[resource]['url']
+        self.assertEqual(url, link['title'])
+        self.assertEqual("%s/%s/" % (self.app.config['SERVER_NAME'], url),
+                         link['href'])
 
     def assertNextLink(self, links, page):
-        found = False
-        for link in links:
-            if "title='next page'" in link and "rel='next'" in link and \
-               'page=%d' % page in link:
-                found = True
-        self.assertTrue(found)
+        self.assertTrue('next' in links)
+        link = links['next']
+        self.assertTrue('title' in link)
+        self.assertTrue('href' in link)
+        self.assertEqual('next page', link['title'])
+        self.assertTrue("page=%d" % page in link['href'])
 
     def assertPrevLink(self, links, page):
-        found = False
-        for link in links:
-            if "title='previous page'" in link and "rel='prev'" in link:
-                if page > 1:
-                    found = 'page=%d' % page in link
-                else:
-                    found = True
-        self.assertTrue(found)
+        self.assertTrue('prev' in links)
+        link = links['prev']
+        self.assertTrue('title' in link)
+        self.assertTrue('href' in link)
+        self.assertEqual('previous page', link['title'])
+        if page > 1:
+            self.assertTrue("page=%d" % page in link['href'])
 
-    def assertItemLink(self, link, item_id):
-        self.assertTrue("rel='self'" in link and '/%s/' % item_id in link)
+    def assertItemLink(self, links, item_id):
+        self.assertTrue('self' in links)
+        link = links['self']
+        #TODO we are too deep here to get a hold of the due title. Should fix.
+        self.assertTrue('title' in link)
+        self.assertTrue('href' in link)
+        self.assertTrue('/%s/' % item_id in link['href'])
 
     def assert400(self, status):
         self.assertEqual(status, 400)
@@ -207,41 +223,37 @@ class TestMethodsBase(TestBase):
     def assert412(self, status):
         self.assertEqual(status, 412)
 
-    @classmethod
-    def setUpClass(cls):
-        cls._c = Connection()
-        cls._c.drop_database(MONGO_DBNAME)
-        cls._c[MONGO_DBNAME].add_user(MONGO_USERNAME, MONGO_PASSWORD)
-        cls.bulk_insert()
-        cls._c.close()
+    def setupDB(self):
+        self.connection = Connection()
+        self.connection.drop_database(MONGO_DBNAME)
+        self.connection[MONGO_DBNAME].add_user(MONGO_USERNAME, MONGO_PASSWORD)
+        self.bulk_insert()
 
-    @classmethod
-    def tearDownModule(cls):
-        c = Connection()
-        c.drop_database(MONGO_DBNAME)
-        c.close()
+    def bulk_insert(self):
+        _db = self.connection[MONGO_DBNAME]
+        _db.contacts.insert(self.random_contacts(100))
+        _db.payments.insert(self.random_payments(10))
+        self.connection.close()
 
-    @classmethod
-    def bulk_insert(cls):
-        cls._db = cls._c[MONGO_DBNAME]
-        cls._db.contacts.insert(cls.random_contacts(100))
-        cls._db.payments.insert(cls.random_payments(10))
+    def dropDB(self):
+        self.connection = Connection()
+        self.connection.drop_database(MONGO_DBNAME)
+        self.connection.close()
 
-    @classmethod
-    def random_contacts(cls, num):
+    def random_contacts(self, num):
         schema = DOMAIN['contacts']['schema']
         contacts = []
         for i in range(num):
             dt = datetime.now()
             contact = {
-                'ref':  cls.random_string(schema['ref']['maxlength']),
+                'ref':  self.random_string(schema['ref']['maxlength']),
                 'prog': i,
                 'role': random.choice(schema['role']['allowed']),
-                'rows': cls.random_rows(random.randint(0, 5)),
-                'alist': cls.random_list(random.randint(0, 5)),
+                'rows': self.random_rows(random.randint(0, 5)),
+                'alist': self.random_list(random.randint(0, 5)),
                 'location': {
-                    'address': 'address ' + cls.random_string(5),
-                    'city': 'city ' + cls.random_string(3),
+                    'address': 'address ' + self.random_string(5),
+                    'city': 'city ' + self.random_string(3),
                 },
                 'born': datetime.today() + timedelta(
                     days=random.randint(-10, 10)),
@@ -254,13 +266,12 @@ class TestMethodsBase(TestBase):
             contacts.append(contact)
         return contacts
 
-    @classmethod
-    def random_payments(cls, num):
+    def random_payments(self, num):
         payments = []
         for i in range(num):
             dt = datetime.now()
             payment = {
-                'a_string':  cls.random_string(10),
+                'a_string':  self.random_string(10),
                 'a_number': i,
                 eve.LAST_UPDATED: dt,
                 eve.DATE_CREATED: dt,
@@ -268,28 +279,24 @@ class TestMethodsBase(TestBase):
             payments.append(payment)
         return payments
 
-    @classmethod
-    def random_string(cls, num):
+    def random_string(self, num):
         return (''.join(random.choice(string.ascii_uppercase)
                         for x in range(num)))
 
-    @classmethod
-    def random_list(cls, num):
+    def random_list(self, num):
         alist = []
         for i in range(num):
             alist.append(['string' + str(i), random.randint(1000, 9999)])
         return alist
 
-    @classmethod
-    def random_rows(cls, num):
+    def random_rows(self, num):
         schema = DOMAIN['contacts']['schema']['rows']['items']
         rows = []
         for i in range(num):
             rows.append(
                 {
-                    'sku': cls.random_string(schema['sku']['maxlength']),
+                    'sku': self.random_string(schema['sku']['maxlength']),
                     'price': random.randint(100, 1000),
                 }
             )
         return rows
-        return rows
