@@ -13,8 +13,8 @@ class TestDelete(TestMethodsBase):
         r, status = self.parse_response(self.test_client.get(
             self.known_resource_url))
         self.assert200(status)
-        self.assertEqual(len(r[self.known_resource]), 0)
-        TestDelete.bulk_insert()
+        self.assertEqual(len(r['_items']), 0)
+        self.bulk_insert()
 
     def test_delete_empty_resource(self):
         url = '%s%s/' % (self.empty_resource_url, self.item_id)
