@@ -9,7 +9,7 @@ ID_FIELD = '_id'
 
 SERVER_NAME = 'localhost:5000'
 
-RESOURCE_METHODS = ['GET', 'POST']
+RESOURCE_METHODS = ['GET', 'POST', 'DELETE']
 ITEM_METHODS = ['GET', 'PATCH', 'DELETE']
 ITEM_CACHE_CONTROL = ''
 ITEM_LOOKUP = True
