@@ -12,4 +12,4 @@ class Validator(Validator):
 
 if __name__ == '__main__':
     app = Eve(validator=Validator)
-    app.run()
+    app.run(debug=True)
